@@ -6,7 +6,7 @@ if (getRversion() >= "3.1.0") {
 #' ganttStatus
 #'
 #' Internal function assign the "status" of each event to be passed to
-#' \code{\link[DiagrammeR]{mermaid}} to make a Gantt chart representing the
+#' \code{DiagrammeR::mermaid} to make a Gantt chart representing the
 #' events in a completed simulation.
 #' 'init' events are set as "done"; 'plot' events as "critical"; and all others
 #' as "active".
@@ -46,7 +46,7 @@ setMethod("ganttStatus",
 #'
 #' Internal function to convert the completed events list of a \code{simList}
 #' object to a list of \code{data.frame}s suitable to pass to a call to
-#' \code{\link[DiagrammeR]{mermaid}} to make a Gantt chart representing the
+#' \code{DiagrammeR::mermaid} to make a Gantt chart representing the
 #' events in a completed simulation.
 #'
 #' @param sim  A \code{simList} object (typically corresponding to a
@@ -134,10 +134,9 @@ setMethod(
 #'
 #' @return Plots an event diagram as Gantt Chart, invisibly returning a \code{mermaid} object.
 #'
-#' @seealso \code{\link[DiagrammeR]{mermaid}}.
+#' @seealso \code{DiagrammeR::mermaid}.
 #'
 #' @include simList-accessors.R
-#' @importFrom DiagrammeR mermaid
 #' @export
 #' @rdname eventDiagram
 #'
@@ -154,6 +153,8 @@ setMethod(
   signature(sim = "simList", n = "numeric", startDate = "character"),
   definition = function(sim, n, startDate, ...) {
     # get automatic scaling of vertical bars in Gantt chart
+    needInstall("DiagrammeR", minVersion = "0.8.2",
+                messageStart = "Please install DiagrammeR: ")
     dots <- list(...)
     dots$width <- if (any(grepl(pattern = "width", names(dots)))) {
       as.numeric(dots$width)
@@ -185,7 +186,7 @@ setMethod(
                  df$start, ",", df$end, collapse = "\n")
         }), collapse = "\n"), "\n"
       )
-      do.call(mermaid, args = append(diagram, dots))
+      do.call(DiagrammeR::mermaid, args = append(diagram, dots))
     } else {
       stop("Unable to create eventDiagram for a simulation that hasn't been run.\n",
            "Run your simulation using `mySim <- spades(mySim)` and try again.")
@@ -221,15 +222,15 @@ setMethod(
 #' @param sim  A \code{simList} object (typically corresponding to a
 #'             completed simulation).
 #'
-#' @param ...  Additional arguments passed to \code{mermaid}.
+#' @param ...  Additional arguments passed to \code{DiagrammeR::mermaid}.
 #'             Useful for specifying \code{height} and \code{width}.
 #'
-#' @return Plots a sequence diagram, invisibly returning a \code{mermaid} object.
+#' @return Plots a sequence diagram, invisibly returning a
+#'   \code{DiagrammeR::mermaid} object.
 #'
-#' @seealso \code{\link[DiagrammeR]{mermaid}}.
+#' @seealso \code{DiagrammeR::mermaid}.
 #'
 #' @include simList-accessors.R
-#' @importFrom DiagrammeR mermaid
 #' @export
 #' @rdname objectDiagram
 #'
@@ -246,6 +247,8 @@ setMethod(
   signature(sim = "simList"),
   definition = function(sim, ...) {
     dt <- depsEdgeList(sim, FALSE)
+    needInstall("DiagrammeR", minVersion = "0.8.2",
+                messageStart = "Please install DiagrammeR: ")
     DiagrammeR::mermaid(...,
       paste0(
         # mermaid "header"
