@@ -156,7 +156,6 @@ setMethod(
 #' @return A \code{simList} simulation object.
 #'
 #' @author Alex Chubaty and Eliot McIntire
-#' @importFrom codetools checkUsageEnv findGlobals
 #' @importFrom reproducible Cache
 #' @include environment.R
 #' @include module-dependencies-class.R
@@ -479,10 +478,13 @@ setMethod(
 evalWithActiveCode <- function(parsedModuleNoDefineModule, envir, parentFrame = parent.frame(),
                                sim) {
 
+  browser(expr = exists("._evalWithActiveCode_1"))
   # Create a temporary environment to source into, adding the sim object so that
   #   code can be evaluated with the sim, e.g., currentModule(sim)
   tmpEnvir <- new.env(parent = envir)
-  tmpEnvir$sim <- sim
+
+  # This needs to be unconnected to main sim so that object sizes don't blow up
+  tmpEnvir$sim <- Copy(sim, objects = FALSE)
 
   ll <- lapply(parsedModuleNoDefineModule,
                function(x) tryCatch(eval(x, envir = tmpEnvir),
@@ -494,6 +496,7 @@ evalWithActiveCode <- function(parsedModuleNoDefineModule, envir, parentFrame =
   rm(tmpEnvir)
 
   if (any(activeCode)) {
+    browser(expr = exists("._evalWithActiveCode_2"))
     env <- new.env(parent = parentFrame);
     aa <- lapply(parsedModuleNoDefineModule[activeCode], function(ac) {
       eval(ac, envir = env)
