@@ -199,16 +199,54 @@ test_that("simList object initializes correctly (1)", {
   rm(mySim)
 })
 
-test_that("simList test all signatures", {
-  testInitOut <- testInit(opts = list(spades.moduleCodeChecks = FALSE))
+test_that("simList object initializes correctly (2)", {
+  testInitOut <- testInit("raster")
   on.exit({
     testOnExit(testInitOut)
   }, add = TRUE)
+  ## test with outputs
+  ras <- raster::raster(nrows = 10, ncols = 10, xmn = -5, xmx = 5, ymn = -5, ymx = 5)
+  abundRasters <- list(SpaDES.tools::gaussMap(ras, scale = 100, var = 0.01))
+
+  tmpdir <- tempdir()
+  newModule(name = "test", path = file.path(tmpdir, "modules"), open = FALSE)
+  obj <- list(abundRasters = abundRasters)#, tempRasters = tempRasters)
+  paths <- list(modulePath = file.path(tmpdir, "modules"))
+
+  ## If start is set to 1.0, there is a warning message and spades doesn't seem to run
+  aa <- (capture_warnings({
+    mySim <- simInit(times = list(start = 1.0, end = 2.0),
+                     modules = list("test"), paths = paths,
+                     objects = obj)
+    }))
+  expect_length(aa, 0)
+})
+
+test_that("simList test all signatures", {
+  testInitOut <- testInit(opts = list(spades.moduleCodeChecks = FALSE))
+
+  on.exit({
+    testOnExit(testInitOut)
+    if (!curPathIsPkgPath) {
+      setPaths(modulePath = origDir)
+    }
+  }, add = TRUE)
   # times
   times <- list(start = 0.0, end = 10)
 
   # modules
-  modules <- list("randomLandscapes", "caribouMovement", "fireSpread")
+  modules <- list("randomLandscapes")#, "caribouMovement", "fireSpread")
+  curPathIsPkgPath <- (identical(
+    normPath(system.file("sampleModules", package = "SpaDES.core")),
+    normPath(getwd())))
+  if (!curPathIsPkgPath) { # on a R CMD check, these paths are same, so don't copy
+    modPaths <- dir(system.file("sampleModules", package = "SpaDES.core"),
+                    recursive = TRUE, full.names = TRUE)
+    modPaths <- grep(paste(modules, collapse = "|"), modPaths, value = TRUE)
+    file.copy(dirname(modPaths), recursive = TRUE, to = ".")
+    origDir <- getOption("spades.modulePath", getwd())
+    setPaths(modulePath = getwd())
+  }
 
   # paths
   mapPath <- system.file("maps", package = "quickPlot")
@@ -251,7 +289,7 @@ test_that("simList test all signatures", {
     )
 
     # loadOrder
-    loadOrder <- c("randomLandscapes", "caribouMovement", "fireSpread")
+    loadOrder <- c("randomLandscapes")#, "caribouMovement", "fireSpread")
 
     # test all argument combinations to simInit
     N <- 256L
@@ -273,42 +311,22 @@ test_that("simList test all signatures", {
                     "outputs", "loadOrder")
       names(li) <- argNames
       li <- li[!sapply(li, is.null)]
-      successes[i] <- tryCatch(
+      messes <- capture_messages(successes[i] <- tryCatch(
         is(do.call(simInit, args = li), "simList"),
         error = function(e) { FALSE },
         warning = function(w) { FALSE }
-      )
+      ))
       argsTested[[i]] <- names(li)
     }
 
     # needs paths and params; many defaults are fine
     expect_equal(sum(successes, na.rm = TRUE), 256)
+    if (FALSE) {
+      dt <- data.table(lapply(argsTested, paste, collapse = "_"), successes)
+    }
   }
 })
 
-test_that("simList object initializes correctly (2)", {
-  testInitOut <- testInit("raster")
-  on.exit({
-    testOnExit(testInitOut)
-  }, add = TRUE)
-  ## test with outputs
-  ras <- raster::raster(nrows = 10, ncols = 10, xmn = -5, xmx = 5, ymn = -5, ymx = 5)
-  abundRasters <- list(SpaDES.tools::gaussMap(ras, scale = 100, var = 0.01))
-
-  tmpdir <- tempdir()
-  newModule(name = "test", path = file.path(tmpdir, "modules"), open = FALSE)
-  obj <- list(abundRasters = abundRasters)#, tempRasters = tempRasters)
-  paths <- list(modulePath = file.path(tmpdir, "modules"))
-
-  ## If start is set to 1.0, there is a warning message and spades doesn't seem to run
-  aa <- (capture_warnings({
-    mySim <- simInit(times = list(start = 1.0, end = 2.0),
-                     modules = list("test"), paths = paths,
-                     objects = obj)
-    }))
-  expect_length(aa, 0)
-})
-
 test_that("childModule bug test -- created infinite loop of 'Duplicated...'", {
   ## Test resulting from bug found by Greg Paradis April 7, 2019
   testInitOut <- testInit("raster")
